package Sourceyard::Controller;

use strict;
use warnings;
use Mojo::Base 'Mojolicious::Controller';

use Sourceyard::User;
use Sourceyard::Statistics;

sub new {
    my $class = shift;
    my $self = $class->SUPER::new(@_);
    $self->set_user;
    return $self;
}

sub clone {
    my ($class,$obj) = @_;
    my $self = bless $obj, $class;
    $self->set_user;
    return $self;
}

sub set_user {
    my ($self, $user) = @_;
    if (defined($user)) {
	$self->session(logged_in => 1);
	$self->session(username => $user->user_name);
    } elsif (my $username = $self->session('username')) {
	$user = new Sourceyard::User($self, $username);
	unless ($user) {
	    $self->session(expires => 1);
	}
    }

    my $theme;
    
    if ($user) {
	$self->stash(user => $user);
	$theme = ucfirst($user->theme);
    }
    
    unless (defined($theme)
	    && -f ${$self->app->static->paths}[0] . '/css/' . $theme . '.css') {
	$theme = $self->config->get(qw(core theme));
    }
    $self->stash(theme => $theme);
}

sub statistics {
    my $self = shift;
    return $self->{_sy_stat} ||= new Sourceyard::Statistics($self);
}

1;
